==> vtiger-4.0p1_1.tbz: www/vtiger/modules/System/includes/lang/de.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: de.php,v 1.1 2005/03/14 07:42:10 shankarr Exp $

$text['title']          = 'System Information';

$text['vitals']         = 'System &Uuml;bersicht';
$text['hostname']       = 'Zugewiesener Hostname';
$text['ip']             = '&Uuml;berwachte IP';
$text['kversion']       = 'Kernel Version';
$text['dversion']       = 'Distro Name';
$text['uptime']         = 'Betriebszeit';
$text['users']          = 'Eingeloggte Benutzer';
$text['loadavg']        = 'Auslastung';

$text['hardware']       = 'Hardware &Uuml;bersicht';
$text['numcpu']         = 'Prozessoren';
$text['cpumodel']       = 'Modell';
$text['mhz']            = 'Taktfrequenz';
$text['cache']          = 'Cachegr&ouml;&szlig;e';
$text['bogomips']       = 'System Bogomips';
$text['usb']            = 'USB Ger&auml;te';
$text['pci']            = 'PCI Ger&auml;te';
$text['ide']            = 'IDE Ger&auml;te';
$text['scsi']           = 'SCSI Ger&auml;te';

$text['netusage']       = 'Netzwerk-Auslastung';
$text['device']         = 'Schnittstelle';
$text['received']       = 'Empfangen';
$text['sent']           = 'Gesendet';
$text['errors']         = 'Fehler/Verworfen';

$text['memusage']       = 'Speicher-Auslastung';
$text['phymem']         = 'Physikalischer Speicher';
$text['swap']           = 'Auslagerungsdatei';

$text['fs']             = 'Angemeldete Filesysteme';
$text['mount']          = 'Mount';
$text['partition']      = 'Partition';

$text['percent']        = 'Prozentuale Auslastung';
$text['type']           = 'Typ';
$text['free']           = 'Frei';
$text['used']           = 'Benutzt';
$text['size']           = 'Gr&ouml;&szlig;e';
$text['totals']         = 'Insgesamt';

$text['kb']             = 'KiB';
$text['mb']             = 'MiB';
$text['gb']             = 'GiB';

$text['none']           = 'keine';

$text['capacity']       = 'Kapazitt';
  
$text['template']       = 'Vorlage';
$text['language']       = 'Sprache';
$text['submit']         = 'ndern';
$text['created']        = 'Erstellt von';
$text['locale']         = 'de_DE';
$text['gen_time']       = 'am %d.%b %Y um %R';

$text['days']           = 'Tage';
$text['hours']          = 'Stunden';
$text['minutes']        = 'Minuten';
  
$text['temperature']    = 'Temperatur';
$text['voltage']        = 'Spannungen';
$text['fans']           = 'L&uuml;fter';
$text['s_value']        = 'Wert';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['s_div']          = 'Div';
$text['hysteresis']     = 'Hysteresis';
$text['s_limit']        = 'Grenzwert';
$text['s_label']        = 'Bezeichnung';
$text['degree_mark']    = '&ordm;C';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

?>

==> vtiger-4.2.4.tbz: www/vtiger/modules/System/includes/lang/de.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: de.php,v 1.13 2004/08/30 15:51:26 webbie Exp $

$text['title']          = 'System Information';

$text['vitals']         = 'System &Uuml;bersicht';
$text['hostname']       = 'Zugewiesener Hostname';
$text['ip']             = '&Uuml;berwachte IP';
$text['kversion']       = 'Kernel Version';
$text['dversion']       = 'Distro Name';
$text['uptime']         = 'Betriebszeit';
$text['users']          = 'Eingeloggte Benutzer';
$text['loadavg']        = 'Auslastung';

$text['hardware']       = 'Hardware &Uuml;bersicht';
$text['numcpu']         = 'Prozessoren';
$text['cpumodel']       = 'Modell';
$text['cpuspeed']       = 'Taktfrequenz';
$text['busspeed']       = 'BUS Speed';
$text['cache']          = 'Cachegr&ouml;&szlig;e';
$text['bogomips']       = 'System Bogomips';

$text['pci']            = 'PCI Ger&auml;te';
$text['ide']            = 'IDE Ger&auml;te';
$text['scsi']           = 'SCSI Ger&auml;te';
$text['usb']            = 'USB Ger&auml;te';

$text['netusage']       = 'Netzwerk-Auslastung';
$text['device']         = 'Schnittstelle';
$text['received']       = 'Empfangen';
$text['sent']           = 'Gesendet';
$text['errors']         = 'Fehler/Verworfen';

$text['memusage']       = 'Speicher-Auslastung';
$text['phymem']         = 'Physikalischer Speicher';
$text['swap']           = 'Auslagerungsdatei';

$text['fs']             = 'Angemeldete Filesysteme';
$text['mount']          = 'Mount';
$text['partition']      = 'Partition';

$text['percent']        = 'Prozentuale Auslastung';
$text['type']           = 'Typ';
$text['free']           = 'Frei';
$text['used']           = 'Benutzt';
$text['size']           = 'Gr&ouml;&szlig;e';
$text['totals']         = 'Insgesamt';

$text['kb']             = 'KiB';
$text['mb']             = 'MiB';
$text['gb']             = 'GiB';

$text['none']           = 'keine';

$text['capacity']       = 'Kapazitt';
  
$text['template']       = 'Vorlage';
$text['language']       = 'Sprache';
$text['submit']         = 'ndern';
$text['created']        = 'Erstellt von';
$text['locale']         = 'de_DE';
$text['gen_time']       = 'am %d.%b %Y um %R';

$text['days']           = 'Tage';
$text['hours']          = 'Stunden';
$text['minutes']        = 'Minuten';
  
$text['temperature']    = 'Temperatur';
$text['voltage']        = 'Spannungen';
$text['fans']           = 'L&uuml;fter';
$text['s_value']        = 'Wert';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['s_div']          = 'Div';
$text['hysteresis']     = 'Hysteresis';
$text['s_limit']        = 'Grenzwert';
$text['s_label']        = 'Bezeichnung';
$text['degree_mark']    = '&ordm;C';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

?>
